# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-Pod-Eventual
Version:	0.094003
Release:	2.%{__distinit}%{__distvers}
Summary:	Read a POD document as a series of trivial events
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/Pod-Eventual
Source0:	https://cpan.metacpan.org/modules/by-module/Pod/Pod-Eventual-%{version}.tar.gz
Patch0:		Pod-Eventual-0.094003-old-EU:MM.patch
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(:VERSION) >= 5.12
BuildRequires:	perl(ExtUtils::MakeMaker) >= 6.31
# Module Runtime
BuildRequires:	perl(Carp)
BuildRequires:	perl(Mixin::Linewise::Readers) >= 0.102
BuildRequires:	perl(strict)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(Test::Deep)
BuildRequires:	perl(Test::More) >= 0.96
# Optional Tests
BuildRequires:	perl(CPAN::Meta) >= 2.120900
# Extra Tests
BuildRequires:	perl(Encode)
BuildRequires:	perl(Test::Pod) >= 1.41
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif
# Old provides generator does not support the syntax used in this module
%if 0%{?fedora} < 21 && 0%{?rhel} < 8
Provides:	perl(Pod::Eventual) = %{version}
Provides:	perl(Pod::Eventual::Simple) = %{version}
%endif

%description
POD is a pretty simple format to write, but it can be a big pain to deal with
reading it and doing anything useful with it. Most existing POD parsers care
about semantics, like whether a =item occurred after an =over but before a
back, figuring out how to link a L<>, and other things like that.

Pod::Eventual is much less ambitious and much more stupid. Fortunately, stupid
is often better (that's what I keep telling myself, anyway).

Pod::Eventual reads line-based input and produces events describing each POD
paragraph or directive it finds. Once complete events are immediately passed to
the handle_event method. This method should be implemented by Pod::Eventual
sub-classes. If it isn't, Pod::Eventual's own handle_event will be called, and
will raise an exception.

%prep
%setup -q -n Pod-Eventual-%{version}

# Avoid the need for ExtUtils::MakeMaker ≥ 6.78
%patch -P 0

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test
make test TEST_FILES="$(echo $(find xt/ -name '*.t'))"

%files
%license LICENSE
%doc Changes README
%{perl_vendorlib}/Pod/
%{_mandir}/man3/Pod::Eventual.3*
%{_mandir}/man3/Pod::Eventual::Simple.3*

%changelog
* Thu Jul 13 2023 Paul Howarth <paul@city-fan.org> - 0.094003-2
- Avoid use of deprecated patch syntax

* Sun Jan  1 2023 Paul Howarth <paul@city-fan.org> - 0.094003-1
- Update to 0.094003
  - Update author contact info
- Use SPDX-format license tag

* Mon Jul  5 2021 Paul Howarth <paul@city-fan.org> - 0.094002-1
- Update to 0.094002
  - Fix typo
  - Update author contact info
  - Document perl version policy
- Add manual provides for old distribution versions
- Use %%license unconditionally

* Mon Jun  3 2019 Paul Howarth <paul@city-fan.org> - 0.094001-13
- Perl 5.30 rebuild

* Mon Apr 16 2018 Paul Howarth <paul@city-fan.org> - 0.094001-9
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - Drop workaround for building with Test::More < 0.88

* Wed Sep 21 2016 Paul Howarth <paul@city-fan.org> - 0.094001-5
- Classify buildreqs by usage
- Simplify find command using -delete

* Wed Sep 10 2014 Paul Howarth <paul@city-fan.org> - 0.094001-2
- Drop %%defattr, redundant since rpm 4.4
- Drop support for building with ExtUtils::MakeMaker < 6.30
- Use %%license where possible

* Wed Nov  6 2013 Paul Howarth <paul@city-fan.org> - 0.094001-1
- Update to 0.094001
  - Require Mixin-Linewise 0.102 to avoid busted 0.101

* Sun Oct 20 2013 Paul Howarth <paul@city-fan.org> - 0.094000-1
- Update to 0.094000
  - Tiny documentation tweak

* Sun Oct 13 2013 Paul Howarth <paul@city-fan.org> - 0.093331-1
- Update to 0.093331
  - Update repo and bug tracker
- Add patches to support building with ExtUtils::MakeMaker < 6.30 and
  Test::More < 0.94
- Explicitly run the extra tests

* Mon Jul 16 2012 Paul Howarth <paul@city-fan.org> - 0.093330-10
- Perl 5.16 post-bootstrap rebuild

* Fri Jul  6 2012 Paul Howarth <paul@city-fan.org> - 0.093330-9
- BR: perl(Carp)
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Always use Test::Deep
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Sat Jul  2 2011 Paul Howarth <paul@city-fan.org> - 0.093330-6
- Rebuild for perl 5.14.1 in Rawhide
- Add support for perl_bootstrap macro
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Wed Jun 23 2010 Paul Howarth <paul@city-fan.org> - 0.093330-5
- Rebuild for perl 5.12.1 in Rawhide

* Tue May 11 2010 Paul Howarth <paul@city-fan.org> - 0.093330-4
- Fix dist tag for RHEL-6 Beta

* Wed Feb  3 2010 Paul Howarth <paul@city-fan.org> - 0.093330-3
- BR: perl(Pod::Coverage::TrustPod) for extra test cover (note that this
  introduces a build dependency loop that will need to be worked around if
  bootstrapping new releases)

* Wed Feb  3 2010 Paul Howarth <paul@city-fan.org> - 0.093330-2
- Import from Fedora
- Add patch to support build on Perl 5.8.0 where we have no Test::Deep

* Thu Jan 14 2010 Iain Arnell 0.093330-1
- Specfile autogenerated by cpanspec 1.78
